@@ -1,4 +1,4 @@
-/* readinputfile.h -- This file is part of Archimedes release 0.7.0
+/* readinputfile.h -- This file is part of Archimedes release 1.2.0
    Archimedes is a simulator for Submicron 2D III-V semiconductor
    Devices. It implements the Monte Carlo method and Hybrid MEP model
    for the simulation of the semiclassical Boltzmann equation for both
@@ -6,7 +6,7 @@
    of effective potential method. It is now able to simulate applied
    magnetic fields along with self consistent Faraday equation.
 
-   Copyright (C) 2004, 2005, 2006, 2007 Jean Michel Sellier <sellier@dmi.unict.it>
+   Copyright (C) 2004-2011 Jean Michel Sellier <sellier@dmi.unict.it>
  
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -23,10 +23,10 @@
 */
 
 
-// ######################################################
+// ##################################################################
 // Created on 10 sep.2004, Siracusa, J.M.Sellier
-// Last modif. : 23 september 2007, Siracusa, J.M.Sellier
-// ######################################################
+// Last modif. : 19 august 2011, Carry le Rouet, France, J.M.Sellier
+// ##################################################################
 
 // Read the geometrical and physical description of the device.
 // The input file is interpreted as in a script language.
@@ -48,6 +48,10 @@ Read_Input_File(void)
 // in the input file we have
 // the following values.
 // ============================
+ OPTICALPHONONS=ON;  // Optical phonons scattering ON by default
+ ACOUSTICPHONONS=ON; // Acoustic phonons scattering ON by default
+ IMPURITYPHONONS=ON; // Impurity phonons scattering ON by default
+ CONDUCTION_BAND=KANE;   // Kane approximation by default
  XVAL[ALXINXSB]=XVAL[ALXIN1XSB]=XVAL[INXGA1XAS]=XVAL[INXAL1XAS]=XVAL[INXGAXXAS]=0.5;
  Model_Number=MCE; // here we choose the model
  nx=50; // default # of cells in x-direction
@@ -55,7 +59,6 @@ Read_Input_File(void)
  TF=5.0e-12; // Default Final Time in seconds
  DT=0.001e-12; // Default constant time step
  TAUW=0.4e-12; // Default Energy relaxation time
- msh=mstarHSILICON; // coefficient of the Si heavy hole effective mass
  FARADAYFLAG=0; // no evolution of magnetic field taken into account as default (B = 0 or const.)
 // standard doping concentration
  for(i=1;i<=nx+1;i++)
@@ -113,15 +116,12 @@ Processing the input file\n\
     fscanf(fp,"%s",s);
     if(strcmp(s,"SILICON")==0){
         type=SILICON;
-        msh=mstarHSILICON;
     }
     else if(strcmp(s,"GAAS")==0){
         type=GAAS;
-        msh=mstarHGAAS;
     }
     else if(strcmp(s,"GERMANIUM")==0){
         type=GERMANIUM;
-        msh=mstarHGERMANIUM;
     }
     else if(strcmp(s,"INSB")==0) type=INSB;
     else if(strcmp(s,"ALSB")==0) type=ALSB;
@@ -255,7 +255,7 @@ Processing the input file\n\
         exit(EXIT_FAILURE);
     }
   }
-// Specified the number of spatial step in x direction
+// Specify the number of cells in x direction
   else if(strcmp(s,"XSPATIALSTEP")==0){
     fscanf(fp,"%lf",&num);
     nx=(int) num;
@@ -267,10 +267,10 @@ Processing the input file\n\
       printf("%s: you have to define the x-length first\n",progname);
       exit(EXIT_FAILURE);
     }
-    dx=LX/nx; // spatial step in x-direction
+    dx=LX/nx; // length of cell in x-direction
     printf("XSPATIALSTEP = %d ---> Ok\n",nx);
   }
-// Specified the number of spatial step in y direction
+// Specify the number of cells in y direction
   else if(strcmp(s,"YSPATIALSTEP")==0){
     fscanf(fp,"%lf",&num);
     ny=(int) num;
@@ -282,10 +282,10 @@ Processing the input file\n\
       printf("%s: you have to define the y-length first\n",progname);
       exit(EXIT_FAILURE);
     }
-    dy=LY/ny; // spatial step in y-direction
+    dy=LY/ny; // length of cell in y-direction
     printf("YSPATIALSTEP = %d ---> Ok\n",ny);
   }
-// configuration of the final time of simulation
+// specify the final time of simulation
   else if(strcmp(s,"FINALTIME")==0){
     fscanf(fp,"%lg",&num);
     TF=num;
@@ -782,6 +782,75 @@ Processing the input file\n\
         }
     printf("Constant Magnetic Field %f %f %f %f %f ---> Ok\n",xi,yi,xf,yf,value);
   }
+  else if(strcmp(s,"OPTICALSCATTERING")==0){
+// specify if the Optical phonons scateering has to be taken into account
+   fscanf(fp,"%s",s);
+   if(strcmp(s,"ON")==0){
+    OPTICALPHONONS=ON;
+    printf("OPTICAL PHONONS SCATTERING = ON ---> Ok\n");
+   }
+   else if(strcmp(s,"OFF")==0){
+    OPTICALPHONONS=OFF;
+    printf("OPTICAL PHONONS SCATTERING = OFF ---> Ok\n");
+   }
+   else {
+    printf("%s : command OPTICALSCATTERING accept ON or OFF.\n",progname);
+    exit(0);
+   }
+  }
+  else if(strcmp(s,"ACOUSTICSCATTERING")==0){
+// specify if the Acoustic phonons scattering has to be taken into account
+   fscanf(fp,"%s",s);
+   if(strcmp(s,"ON")==0){
+    ACOUSTICPHONONS=ON;
+    printf("ACOUSTIC PHONONS SCATTERING = ON ---> Ok\n");
+   }
+   else if(strcmp(s,"OFF")==0){
+    ACOUSTICPHONONS=OFF;
+    printf("ACOUSTIC PHONONS SCATTERING = OFF ---> Ok\n");
+   }
+   else {
+    printf("%s : command ACOUSTINGSCATTERING accept ON or OFF.\n",progname);
+    exit(0);
+   }
+  }
+  else if(strcmp(s,"IMPURITYSCATTERING")==0){
+// specify if the Acoustic phonons scattering has to be taken into account
+   fscanf(fp,"%s",s);
+   if(strcmp(s,"ON")==0){
+    IMPURITYPHONONS=ON;
+    printf("IMPURITY PHONONS SCATTERING = ON ---> Ok\n");
+   }
+   else if(strcmp(s,"OFF")==0){
+    IMPURITYPHONONS=OFF;
+    printf("IMPURITY PHONONS SCATTERING = OFF ---> Ok\n");
+   }
+   else {
+    printf("%s : command IMPURITYSCATTERING accept ON or OFF.\n",progname);
+    exit(0);
+   }
+  }
+  else if(strcmp(s,"CONDUCTIONBAND")==0){
+// Specify the conduction band model
+// Possible choices are PARABOLIC, KANE, FULL
+   fscanf(fp,"%s",s);
+   if(strcmp(s,"PARABOLIC")==0){
+    CONDUCTION_BAND=PARABOLIC;
+    printf("CONDUCTION BAND = PARABOLIC ---> Ok\n");
+   }
+   else if(strcmp(s,"KANE")==0){
+    CONDUCTION_BAND=KANE;
+    printf("CONDUCTION BAND = KANE ---> Ok\n");
+   }
+   else if(strcmp(s,"FULL")==0){
+    CONDUCTION_BAND=FULL;
+    printf("CONDUCTION BAND = FULL BAND ---> Ok\n");
+   }
+   else {
+    printf("%s : Unknown specified conduction band model.\n",progname);
+    exit(0);
+   }
+  }
 // elseif(strcmp(s,"")==0){
  }while(!feof(fp));
 // computation of the maximum doping density
